Struct rosu_mods::generated_mods::AccuracyChallengeCatch
source · pub struct AccuracyChallengeCatch {
pub minimum_accuracy: Option<f32>,
pub accuracy_judge_mode: Option<String>,
pub restart: Option<bool>,
}Expand description
Fail if your accuracy drops too low!
Fields
minimum_accuracy: Option<f32>Trigger a failure if your accuracy goes below this value.
accuracy_judge_mode: Option<String>The mode of accuracy that will trigger failure.
restart: Option<bool>Automatically restarts when failed.
Implementations
sourceimpl AccuracyChallengeCatch
impl AccuracyChallengeCatch
sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of AccuracyChallengeCatch
sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with AccuracyChallengeCatch
sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of AccuracyChallengeCatch
sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind