Struct rosu_mods::generated_mods::CoverMania
source · pub struct CoverMania {
pub coverage: Option<f32>,
pub direction: Option<String>,
}Expand description
Decrease the playfield’s viewing area.
Fields
coverage: Option<f32>The proportion of playfield height that notes will be hidden for.
direction: Option<String>The direction on which the cover is applied
Implementations
sourceimpl CoverMania
impl CoverMania
sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of CoverMania
sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with CoverMania
sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of CoverMania
sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of CoverMania