pub struct MutedMania {
pub inverse_muting: Option<bool>,
pub enable_metronome: Option<bool>,
pub mute_combo_count: Option<f64>,
pub affects_hit_sounds: Option<bool>,
}Expand description
Can you still feel the rhythm without music?
Fields
inverse_muting: Option<bool>Increase volume as combo builds.
enable_metronome: Option<bool>Add a metronome beat to help you keep track of the rhythm.
mute_combo_count: Option<f64>The combo count at which point the track reaches its final volume.
affects_hit_sounds: Option<bool>Hit sounds are also muted alongside the track.
Implementations
Sourceimpl MutedMania
impl MutedMania
Sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of MutedMania
Sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with MutedMania
Sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of MutedMania
Sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of MutedMania