#[repr(transparent)]pub struct StrictTrackingOsu {}Expand description
Once you start a slider, follow precisely or get a miss.
Implementations
Sourceimpl StrictTrackingOsu
impl StrictTrackingOsu
Sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of StrictTrackingOsu
Sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with StrictTrackingOsu
Sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of StrictTrackingOsu
Sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of StrictTrackingOsu