Struct rosu_mods::Acronym

source ·
pub struct Acronym(/* private fields */);
The acronym of a GameMod.

Implementations

source

impl Acronym

source

pub const unsafe fn from_str_unchecked(s: &str) -> Self

Create an Acronym from a string.

Safety

The given string must consist of two or three bytes representing capitalized ASCII letters or digits.

Example
use rosu_mods::Acronym;

let hd = unsafe { Acronym::from_str_unchecked("HD") };
assert_eq!(hd.as_str(), "HD");

Each of the following may lead to undefined behavior, don’t do that!

let _ = unsafe { Acronym::from_str_unchecked("HDHR") }; // must be 2 or 3 characters
let _ = unsafe { Acronym::from_str_unchecked("hd") };   // must be uppercase
source

pub fn as_str(&self) -> &str

Returns the Acronym as a string.

Example
use rosu_mods::Acronym;

let hd = "HD".parse::<Acronym>().unwrap();
assert_eq!(hd.as_str(), "HD");