pub struct GameModSimpleConversionError { /* private fields */ }Available on crate feature
serde only.Expand description
Error returned by GameModSimple::try_as_mod.
This is produced when the settings stored in a GameModSimple are
incompatible with the target GameMod variant — for example when a
value has the wrong type for its field, or when an unrecognised field key
is encountered and deny_unknown_fields is true.
An unknown acronym is not an error; GameModSimple::try_as_mod
returns Ok(GameMod::Unknown*(..)) in that case.