GameModsLegacy

Struct GameModsLegacy 

pub struct GameModsLegacy(/* private fields */);
Lightweight bitflag type for legacy mods.

Example

use rosu_mods::GameModsLegacy;

let nomod = GameModsLegacy::default();
assert_eq!(nomod, GameModsLegacy::NoMod);

// Created via bit operations or from a u32
let hdhr_1 = GameModsLegacy::Hidden | GameModsLegacy::HardRock;
let hdhr_2 = GameModsLegacy::from_bits(8 + 16);
assert_eq!(hdhr_1, hdhr_2);

// Various methods for convenience like `contains` and `intersects`.
let ezhdpf = GameModsLegacy::Easy | GameModsLegacy::Hidden | GameModsLegacy::Perfect;
assert!(!ezhdpf.contains(GameModsLegacy::HardRock));
let hdpf = GameModsLegacy::Hidden | GameModsLegacy::Perfect;
assert!(ezhdpf.intersects(hdpf));

// Parsing a `&str`
let hdhrdt = "dthdhr".parse::<GameModsLegacy>().unwrap();
assert_eq!(hdhrdt.bits(), 8 + 16 + 64);

// The Display implementation combines all acronyms
assert_eq!(hdhrdt.to_string(), "HDHRDT".to_string());

// Has an iterator type
let mut iter = GameModsLegacy::from_bits(536871512).iter();
assert_eq!(iter.next(), Some(GameModsLegacy::Hidden));
assert_eq!(iter.next(), Some(GameModsLegacy::HardRock));
assert_eq!(iter.next(), Some(GameModsLegacy::Nightcore));
assert_eq!(iter.next(), Some(GameModsLegacy::ScoreV2));
assert_eq!(iter.next(), None);

Implementations

Source

impl GameModsLegacy

pub const NoMod: Self

pub const NoFail: Self

pub const Easy: Self

pub const TouchDevice: Self

pub const Hidden: Self

pub const HardRock: Self

pub const SuddenDeath: Self

pub const DoubleTime: Self

pub const Relax: Self

pub const HalfTime: Self

pub const Nightcore: Self

pub const Flashlight: Self

pub const Autoplay: Self

pub const SpunOut: Self

pub const Autopilot: Self

pub const Perfect: Self

pub const Key4: Self

pub const Key5: Self

pub const Key6: Self

pub const Key7: Self

pub const Key8: Self

pub const FadeIn: Self

pub const Random: Self

pub const Cinema: Self

pub const Target: Self

pub const Key9: Self

pub const KeyCoop: Self

pub const Key1: Self

pub const Key3: Self

pub const Key2: Self

pub const ScoreV2: Self

pub const Mirror: Self

Source

impl GameModsLegacy

pub const fn clock_rate(self) -> f64

Returns the clock rate for the mods i.e. 1.5 for DT, 0.75 for HT, and 1.0 otherwise.

pub const fn len(self) -> usize

Returns the amount of contained mods.

Example
use rosu_mods::GameModsLegacy;

assert_eq!(GameModsLegacy::NoMod.len(), 0);
let mods = GameModsLegacy::from_bits(8 + 16 + 64 + 128);
assert_eq!(mods.len(), 4);
pub fn iter(self) -> GameModsLegacyIter

Returns an iterator over GameModsLegacy.

Example
use rosu_mods::GameModsLegacy;

let mut iter = GameModsLegacy::from_bits(8 + 16 + 64 + 128).iter();
assert_eq!(iter.next(), Some(GameModsLegacy::Hidden));
assert_eq!(iter.next(), Some(GameModsLegacy::HardRock));
assert_eq!(iter.next(), Some(GameModsLegacy::DoubleTime));
assert_eq!(iter.next(), Some(GameModsLegacy::Relax));
assert_eq!(iter.next(), None);

let mut iter = GameModsLegacy::NoMod.iter();
assert_eq!(iter.next(), Some(GameModsLegacy::NoMod));
assert_eq!(iter.next(), None);
pub fn to_intermode(self) -> GameModsIntermode

Source

impl GameModsLegacy

pub const fn bits(self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn try_from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

Unknown bits are retained.

pub const fn is_empty(self) -> bool

Whether all bits in this flags value are unset.

pub const fn intersects(self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub const fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub const fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.