Struct rosu_mods::generated_mods::ApproachDifferentOsu
source · pub struct ApproachDifferentOsu {
pub scale: Option<f32>,
pub style: Option<String>,
}Expand description
Never trust the approach circles…
Fields
scale: Option<f32>Change the initial size of the approach circle, relative to hit circles.
style: Option<String>Change the animation style of the approach circles.
Implementations
sourceimpl ApproachDifferentOsu
impl ApproachDifferentOsu
sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of ApproachDifferentOsu
sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with ApproachDifferentOsu
sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of ApproachDifferentOsu
sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of ApproachDifferentOsu