Struct rosu_mods::generated_mods::DifficultyAdjustCatch
source · pub struct DifficultyAdjustCatch {
pub circle_size: Option<f32>,
pub approach_rate: Option<f32>,
pub hard_rock_offsets: Option<bool>,
pub drain_rate: Option<f32>,
pub overall_difficulty: Option<f32>,
pub extended_limits: Option<bool>,
}Expand description
Override a beatmap’s difficulty settings.
Fields
circle_size: Option<f32>Override a beatmap’s set CS.
approach_rate: Option<f32>Override a beatmap’s set AR.
hard_rock_offsets: Option<bool>Adjust the patterns as if Hard Rock is enabled.
drain_rate: Option<f32>Override a beatmap’s set HP.
overall_difficulty: Option<f32>Override a beatmap’s set OD.
extended_limits: Option<bool>Adjust difficulty beyond sane limits.
Implementations
sourceimpl DifficultyAdjustCatch
impl DifficultyAdjustCatch
sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of DifficultyAdjustCatch
sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with DifficultyAdjustCatch
sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of DifficultyAdjustCatch
sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of DifficultyAdjustCatch