Struct rosu_mods::generated_mods::StrictTrackingOsu
source · pub struct StrictTrackingOsu {}Expand description
Once you start a slider, follow precisely or get a miss.
Implementations
sourceimpl StrictTrackingOsu
impl StrictTrackingOsu
sourcepub const fn acronym() -> Acronym
pub const fn acronym() -> Acronym
The acronym of StrictTrackingOsu
sourcepub fn incompatible_mods() -> impl Iterator<Item = Acronym>
pub fn incompatible_mods() -> impl Iterator<Item = Acronym>
Iterator of Acronym for mods that are incompatible with StrictTrackingOsu
sourcepub const fn description() -> &'static str
pub const fn description() -> &'static str
The description of StrictTrackingOsu
sourcepub const fn kind() -> GameModKind
pub const fn kind() -> GameModKind
The GameModKind of StrictTrackingOsu