pub struct Acronym(/* private fields */);Expand description
The acronym of a GameMod.
Implementations
sourceimpl Acronym
impl Acronym
sourcepub const unsafe fn from_str_unchecked(s: &str) -> Self
pub const unsafe fn from_str_unchecked(s: &str) -> Self
Create an Acronym from a string.
Safety
The given string must consist of two or three bytes representing capitalized ASCII letters or digits.
Example
use rosu_mods::Acronym;
let hd = unsafe { Acronym::from_str_unchecked("HD") };
assert_eq!(hd.as_str(), "HD");Each of the following may lead to undefined behavior, don’t do that!
let _ = unsafe { Acronym::from_str_unchecked("HDHR") }; // must be 2 or 3 characters
let _ = unsafe { Acronym::from_str_unchecked("hd") }; // must be uppercaseTrait Implementations
sourceimpl Archive for Acronym
Available on crate feature rkyv only.
impl Archive for Acronym
Available on crate feature
rkyv only.sourceimpl<C: ?Sized> CheckBytes<C> for Acronym
Available on crate feature rkyv only.
impl<C: ?Sized> CheckBytes<C> for Acronym
Available on crate feature
rkyv only.type Error = TupleStructCheckError
type Error = TupleStructCheckError
The error that may result from checking the type.
sourceunsafe fn check_bytes<'a>(
value: *const Self,
ctx: &mut C,
) -> Result<&'a Self, TupleStructCheckError>
unsafe fn check_bytes<'a>( value: *const Self, ctx: &mut C, ) -> Result<&'a Self, TupleStructCheckError>
Checks whether the given pointer points to a valid value within the
given context. Read more
sourceimpl<'de> Deserialize<'de> for Acronym
Available on crate feature serde only.
impl<'de> Deserialize<'de> for Acronym
Available on crate feature
serde only.sourcefn deserialize<D: Deserializer<'de>>(d: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(d: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<D: Fallible + ?Sized> Deserialize<Acronym, D> for Acronym
Available on crate feature rkyv only.
impl<D: Fallible + ?Sized> Deserialize<Acronym, D> for Acronym
Available on crate feature
rkyv only.sourceimpl Ord for Acronym
impl Ord for Acronym
sourceimpl PartialEq for Acronym
impl PartialEq for Acronym
sourceimpl PartialOrd for Acronym
impl PartialOrd for Acronym
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl TryFrom<Acronym> for GameModsLegacy
impl TryFrom<Acronym> for GameModsLegacy
impl Copy for Acronym
impl Eq for Acronym
impl StructuralPartialEq for Acronym