Struct rosu_mods::GameModsLegacy
source · pub struct GameModsLegacy(/* private fields */);Expand description
Lightweight bitflag type for legacy mods.
Example
use rosu_mods::GameModsLegacy;
let nomod = GameModsLegacy::default();
assert_eq!(nomod, GameModsLegacy::NoMod);
// Created via bit operations or from a u32
let hdhr_1 = GameModsLegacy::Hidden | GameModsLegacy::HardRock;
let hdhr_2 = GameModsLegacy::from_bits(8 + 16);
assert_eq!(hdhr_1, hdhr_2);
// Various methods for convenience like `contains` and `intersects`.
let ezhdpf = GameModsLegacy::Easy | GameModsLegacy::Hidden | GameModsLegacy::Perfect;
assert!(!ezhdpf.contains(GameModsLegacy::HardRock));
let hdpf = GameModsLegacy::Hidden | GameModsLegacy::Perfect;
assert!(ezhdpf.intersects(hdpf));
// Parsing a `&str`
let hdhrdt = "dthdhr".parse::<GameModsLegacy>().unwrap();
assert_eq!(hdhrdt.bits(), 8 + 16 + 64);
// The Display implementation combines all acronyms
assert_eq!(hdhrdt.to_string(), "HDHRDT".to_string());
// Has an iterator type
let mut iter = GameModsLegacy::from_bits(536871512).iter();
assert_eq!(iter.next(), Some(GameModsLegacy::Hidden));
assert_eq!(iter.next(), Some(GameModsLegacy::HardRock));
assert_eq!(iter.next(), Some(GameModsLegacy::Nightcore));
assert_eq!(iter.next(), Some(GameModsLegacy::ScoreV2));
assert_eq!(iter.next(), None);Implementations
sourceimpl GameModsLegacy
impl GameModsLegacy
pub const NoMod: Self = _
pub const NoFail: Self = _
pub const Easy: Self = _
pub const TouchDevice: Self = _
pub const Hidden: Self = _
pub const HardRock: Self = _
pub const SuddenDeath: Self = _
pub const DoubleTime: Self = _
pub const Relax: Self = _
pub const HalfTime: Self = _
pub const Nightcore: Self = _
pub const Flashlight: Self = _
pub const Autoplay: Self = _
pub const SpunOut: Self = _
pub const Autopilot: Self = _
pub const Perfect: Self = _
pub const Key4: Self = _
pub const Key5: Self = _
pub const Key6: Self = _
pub const Key7: Self = _
pub const Key8: Self = _
pub const FadeIn: Self = _
pub const Random: Self = _
pub const Cinema: Self = _
pub const Target: Self = _
pub const Key9: Self = _
pub const KeyCoop: Self = _
pub const Key1: Self = _
pub const Key3: Self = _
pub const Key2: Self = _
pub const ScoreV2: Self = _
pub const Mirror: Self = _
sourceimpl GameModsLegacy
impl GameModsLegacy
sourcepub const fn clock_rate(self) -> f32
pub const fn clock_rate(self) -> f32
Returns the clock rate for the mods i.e. 1.5 for DT, 0.75 for HT, and 1.0 otherwise.
sourcepub const fn len(self) -> usize
pub const fn len(self) -> usize
Returns the amount of contained mods.
Example
use rosu_mods::GameModsLegacy;
assert_eq!(GameModsLegacy::NoMod.len(), 0);
let mods = GameModsLegacy::from_bits(8 + 16 + 64 + 128);
assert_eq!(mods.len(), 4);sourcepub fn iter(self) -> GameModsLegacyIter ⓘ
pub fn iter(self) -> GameModsLegacyIter ⓘ
Returns an iterator over GameModsLegacy.
Example
use rosu_mods::GameModsLegacy;
let mut iter = GameModsLegacy::from_bits(8 + 16 + 64 + 128).iter();
assert_eq!(iter.next(), Some(GameModsLegacy::Hidden));
assert_eq!(iter.next(), Some(GameModsLegacy::HardRock));
assert_eq!(iter.next(), Some(GameModsLegacy::DoubleTime));
assert_eq!(iter.next(), Some(GameModsLegacy::Relax));
assert_eq!(iter.next(), None);
let mut iter = GameModsLegacy::NoMod.iter();
assert_eq!(iter.next(), Some(GameModsLegacy::NoMod));
assert_eq!(iter.next(), None);sourcepub fn to_intermode(self) -> GameModsIntermode
pub fn to_intermode(self) -> GameModsIntermode
Convert GameModsLegacy to GameModsIntermode.
sourceimpl GameModsLegacy
impl GameModsLegacy
sourcepub const fn bits(self) -> u32
pub const fn bits(self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
sourcepub const fn try_from_bits(bits: u32) -> Option<Self>
pub const fn try_from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
sourcepub const fn from_bits(bits: u32) -> Self
pub const fn from_bits(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Unknown bits are retained.
sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.